@@ -93,8 +93,6 @@ static void     terminal_widget_drag_data_received    (GtkWidget        *widget,
                                                        guint             time);
 static gboolean terminal_widget_key_press_event       (GtkWidget        *widget,
                                                        GdkEventKey      *event);
-static gboolean terminal_widget_scroll_event          (GtkWidget        *widget,
-                                                       GdkEventScroll   *event);
 static void     terminal_widget_open_uri              (TerminalWidget   *widget,
                                                        const gchar      *wlink,
                                                        gint              tag);
@@ -154,7 +152,6 @@ terminal_widget_class_init (TerminalWidgetClass *klass)
   gtkwidget_class->button_press_event = terminal_widget_button_press_event;
   gtkwidget_class->drag_data_received = terminal_widget_drag_data_received;
   gtkwidget_class->key_press_event    = terminal_widget_key_press_event;
-  gtkwidget_class->scroll_event       = terminal_widget_scroll_event;
 
   /**
    * TerminalWidget::get-context-menu:
@@ -689,27 +686,6 @@ terminal_widget_key_press_event (GtkWidget    *widget,
 
 
 
-static gboolean
-terminal_widget_scroll_event (GtkWidget        *widget,
-                              GdkEventScroll   *event)
-{
-  TerminalWidget *terminal   = TERMINAL_WIDGET (widget);
-  gboolean        scroll;
-  GtkAdjustment  *adjustment = gtk_scrollable_get_vadjustment (GTK_SCROLLABLE (widget));
-
-  g_object_get (G_OBJECT (terminal->preferences), "scrolling-on-output", &scroll, NULL);
-
-  /* do not scroll if the user has scrolled upwards */
-  if (scroll == TRUE && gtk_adjustment_get_value (adjustment) + 1 < gtk_adjustment_get_upper (adjustment))
-    vte_terminal_set_scroll_on_output (VTE_TERMINAL (terminal), FALSE);
-  else if (scroll == TRUE)
-    vte_terminal_set_scroll_on_output (VTE_TERMINAL (terminal), TRUE);
-
-  return (*GTK_WIDGET_CLASS (terminal_widget_parent_class)->scroll_event) (widget, event);
-}
-
-
-
 static void
 terminal_widget_open_uri (TerminalWidget *widget,
                           const gchar    *wlink,
